AggressiveMinimize

Struct AggressiveMinimize 

pub struct AggressiveMinimize;
Encode a given numeric value by aggressively minimising its format.

If the float is finite and its fractional part is zero, it first tries to encode it as an integer. If this conversion fails, it falls back to encoding the value as a float.

Examples

If there is no loss in a smaller format, it is encoded with that value

use serde::Serialize;
use messagepack_serde::ser::{to_slice_with_config, AggressiveMinimize};

let mut buf = [0_u8;1];
to_slice_with_config(&1_u16, &mut buf, AggressiveMinimize).unwrap();

let expected = [1_u8]; // 1 encoded in `positive fixint`
assert_eq!(buf,expected);

Floating point without fractional part is encoded as int

use serde::Serialize;
use messagepack_serde::ser::{to_slice_with_config, AggressiveMinimize};

let mut buf = [0_u8;1];
to_slice_with_config(&1.0_f32, &mut buf, AggressiveMinimize).unwrap();

let expected = [1_u8]; // 1 encoded in `positive fixint`
assert_eq!(buf,expected);

f64 is encoded in the same way as f32.

use serde::Serialize;
use messagepack_serde::ser::{to_slice_with_config, AggressiveMinimize};

let mut buf = [0_u8;1];
to_slice_with_config(&1.0_f64, &mut buf, AggressiveMinimize).unwrap();

let expected = [1_u8]; // 1 encoded in `positive fixint`
assert_eq!(buf,expected);