Exact

Struct Exact 

pub struct Exact;
Encode a given numeric value exactly using its native format.

This does not minimise or convert, so the value is written as is.

Examples

u8 is encoded to positive fixint or uint 8

use serde::Serialize;
use messagepack_serde::ser::{to_slice_with_config, Exact};

let mut buf = [0_u8;1];
to_slice_with_config(&1_u8, &mut buf, Exact).unwrap();

let expected = [1_u8]; // 1 encoded in `positive fixint`
assert_eq!(buf,expected);

u16 is encoded to uint 16

use serde::Serialize;
use messagepack_serde::ser::{to_slice_with_config, Exact};

let mut buf = [0_u8;3];
to_slice_with_config(&1_u16, &mut buf, Exact).unwrap();

let expected = [0xcd_u8, 0x00_u8, 1_u8]; // 1 encoded in `uint 16`
assert_eq!(buf,expected);